#include "editdialog.h"
#include "ui_editdialog.h"

#include <QFileDialog>
#include <QMessageBox>

EditDialog::EditDialog(QWidget *parent) :
	QDialog(parent),
	ui(new Ui::EditDialog)
{
	ui->setupUi(this);

	connect(ui->cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
	connect(ui->acceptButton, SIGNAL(clicked()), this, SLOT(acceptButtonClicked()));
	connect(ui->searchButton, SIGNAL(clicked()), this, SLOT(searchButtonClicked()));
}

void EditDialog::acceptButtonClicked()
{
	if((ui->nameEdit->text() != "") && (ui->locationEdit->text() != "")
			&& (ui->descriptionEdit->toPlainText() != ""))
	{
		name = ui->nameEdit->text();
		fileName = ui->locationEdit->text();
		description = ui->descriptionEdit->toPlainText();
		accept();
	}
	else
	{
		QMessageBox::information(this, tr("Empty fields"),
				tr("Please fill in all required information."));
	}
}

void EditDialog::searchButtonClicked()
{
	QString path =
		QFileDialog::getOpenFileName(this, tr("Open Application file"),
				QDir::currentPath(),
				tr("All files (*)"));
	if (path.isEmpty())
		return;
	else
	{
		// Convert to relative path
		QDir dir(QDir::currentPath());
		path = dir.relativeFilePath(path);
		path = "./" + path;
		ui->locationEdit->setText(path);
	}

}

QString EditDialog::getName()
{
	return name;
}

QString EditDialog::getFileName()
{
	return fileName;
}

QString EditDialog::getDescription()
{
	return description;
}

void EditDialog::setName(QString newName)
{
	name = newName;
	ui->nameEdit->setText(name);
}

void EditDialog::setFileName(QString newFileName)
{
	fileName=newFileName;
	ui->locationEdit->setText(fileName);
}

void EditDialog::setDescription(QString newDescription)
{
	description = newDescription;
	ui->descriptionEdit->setText(description);
}

EditDialog::~EditDialog()
{
	delete ui;
}

void EditDialog::changeEvent(QEvent *e)
{
	QDialog::changeEvent(e);
	switch (e->type()) {
		case QEvent::LanguageChange:
			ui->retranslateUi(this);
			break;
		default:
			break;
	}
}
