#include "mainwindow.h"
#include "ui_mainwindow.h"

#include "../touchbuttons.h"
#include "../helpdialog.h"
#include "xdemreader.h"
#include "xdemwriter.h"
#include "settingsdialog.h"

#include <QProcess>
#include <QDebug>
#include <QApplication>
//#include <QMouseDriverFactory>
#include <QMessageBox>
#include <QFileDialog>
#include <QFile>

//#include <QWaitCondition>

//#include <QMutex>

#include <QTimer>

MainWindow::MainWindow(QWidget *parent) :
	QMainWindow(parent),
	ui(new Ui::MainWindow)
{
	const char *chk_path[] = {
		"./demos.xml",
		"/usr/share/in-circuit/demos.xml",
		NULL,
	};
	int i;

	ui->setupUi(this);



	// Maximize window to fullscreen
	this->showFullScreen();

	// Set backgroundcolor: white
	QPalette pal = this->palette();
	pal.setColor(QPalette::Window, Qt::white);
	this->setPalette(pal);

	//Connect signals and slots
	connect(ui->backButton, SIGNAL(clicked()), this, SLOT(backButtonClicked()));
	connect(ui->settingsButton, SIGNAL(clicked()), this, SLOT(settingsButtonClicked()));
	connect(ui->helpButton, SIGNAL(clicked()), this, SLOT(helpButtonClicked()));
	connect(ui->loadButton, SIGNAL(clicked()), this, SLOT(loadButtonClicked()));
	connect(ui->startButton, SIGNAL(clicked()), this, SLOT(startButtonClicked()));

	connect(ui->radioButtonIC, SIGNAL(clicked()), ui->tableWidgetIC, SLOT(show()));
	connect(ui->radioButtonIC, SIGNAL(clicked()), ui->tableWidgetQT, SLOT(hide()));

	connect(ui->radioButtonQT, SIGNAL(clicked()), ui->tableWidgetQT, SLOT(show()));
	connect(ui->radioButtonQT, SIGNAL(clicked()), ui->tableWidgetIC, SLOT(hide()));

	ui->radioButtonIC->click();

	// Init tables
	initTables();

	// Open default file
	fileName = "";
	for(i = 0; chk_path[i]; i++) {
		if(!QFile::exists(chk_path[i])) continue;
		fileName = chk_path[i];
		break;
	}
	if(fileName[0] != '\0') loadXML(fileName);

	running = false;

}

void MainWindow::setUpTable(QTableWidget *tbl) {
	QStringList headers;
	headers << "Name"<<"Location"<<"Description";

	tbl->setColumnCount(4);
	tbl->setHorizontalHeaderLabels(headers);
        tbl->verticalHeader()->hide();
	tbl->hideColumn(1);
	tbl->hideColumn(3);
        tbl->setColumnWidth(0, 120);
	tbl->setCurrentCell(0,0);
}

void MainWindow::initTables()
{
	// Init IC_Table
	setUpTable(ui->tableWidgetIC);
	//Init QT_Table
	setUpTable(ui->tableWidgetQT);

	fileName = "";
}

void MainWindow::settingsButtonClicked()
{
	if(!running)
	{
		SettingsDialog dialog;
		if(QFile::exists(fileName))
			dialog.loadXML(fileName);

		if(dialog.exec() == QDialog::Accepted)
		{
			QString path = dialog.getFileName();
			if(!path.isEmpty())
			{
				fileName = path;
				loadXML(fileName);
			}
		}
	}

}

void MainWindow::helpButtonClicked()
{
	if(!running)
	{
		HelpDialog dialog;
		dialog.loadURL("qrc:///files/AppChooser_Help.html");
		dialog.exec();
	}
}

void MainWindow::loadButtonClicked()
{
	if(!running)
	{
		fileName =
			QFileDialog::getOpenFileName(this,
					tr("Open QDemo XML File"),
					QDir::currentPath(),
					tr("XDEM Files (*.xdem *.xml)"));

		if (fileName.isEmpty())
			return;

		loadXML(fileName);
	}
}

void MainWindow::loadXML(QString fileName)
{
	// Clear tableWidgets
	ui->tableWidgetIC->setRowCount(0);
	ui->tableWidgetQT->setRowCount(0);

	QFile file(fileName);
	if (!file.open(QFile::ReadOnly | QFile::Text)) {
		QMessageBox::warning(this, tr("QXmlStream"),
				tr("Cannot read file %1:\n%2.")
				.arg(fileName)
				.arg(file.errorString()));
		return;
	}

	XdemReader reader(ui->tableWidgetIC, ui->tableWidgetQT);
	if (!reader.read(&file)) {
		QMessageBox::warning(this, tr("QXmlStream Bookmarks"),
				tr("Parse error in file %1:\n\n%2")
				.arg(fileName)
				.arg(reader.errorString()));
	}
}

#define QWS_MOUSE_PROTO	"QWS_MOUSE_PROTO"
#define QWS_MOUSE_SETTING	"Tslib:/dev/input/event0 LinuxInput:/dev/input/event1"
void MainWindow::startButtonClicked()
{
	if(!running)
	{
		// Launch Application
		QObject *parent = NULL;

		QString program = "";
		QString parg = "";
		QTableWidgetItem *item = NULL;
		QTableWidgetItem *arg = NULL;

		if(ui->radioButtonIC->isChecked())
		{
			item = ui->tableWidgetIC->item(ui->tableWidgetIC->currentRow(), 1);
			arg = ui->tableWidgetIC->item(ui->tableWidgetIC->currentRow(), 3);
		} else {
			item = ui->tableWidgetQT->item(ui->tableWidgetQT->currentRow(), 1);
			arg = ui->tableWidgetQT->item(ui->tableWidgetIC->currentRow(), 3);
		}

		if(item != NULL)
			program = item->text();
		if(arg) parg = arg->text();

		qDebug()<< "Launching " << program << " " << parg << endl;

		if(!QFile::exists(program))
			return;

		QStringList arguments;
		arguments << "-qws" << parg; // QT-Applications need to be run as a server

		//qDebug()<< "Launching " << program<<endl;
		QProcess *myProcess = new QProcess(parent);
		QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
		if(!env.contains(QWS_MOUSE_PROTO))
			env.insert(QWS_MOUSE_PROTO, QWS_MOUSE_SETTING);
		myProcess->setProcessEnvironment(env);
		myProcess->start(program, arguments);

		running = true;

		myProcess->waitForFinished(-1);

		//qDebug()<<"Finished "<<program<<endl;

		// Repaint main application to be displayed correctly again
		this->update();
		if(ui->radioButtonIC->isChecked())
		{
			ui->tableWidgetIC->hide();
			ui->tableWidgetIC->show();
		} else
		{
			ui->tableWidgetQT->hide();
			ui->tableWidgetQT->show();
		}

		// Delay reactivation of interface
		QTimer::singleShot(100, this, SLOT(finishedProgramm()));

	}
}

void MainWindow::finishedProgramm()
{
	running = false;
}

void MainWindow::backButtonClicked()
{
	if(!running)
	{
		close();
	}
}


void MainWindow::keyPressEvent(QKeyEvent *event)
{
	//qDebug()<<event->key()<<" ("<<event->text()<<") pressed."<<endl;  

	switch(event->key())
	{
		case touchbuttons::Key_Touch_Left:
			ui->settingsButton->setDown(true);
			break;
		case touchbuttons::Key_Touch_Center:
			ui->backButton->setDown(true);
			break;
		case touchbuttons::Key_Touch_Right:
			ui->helpButton->setDown(true);
			break;
		default:
			break;
	}
}

void MainWindow::keyReleaseEvent(QKeyEvent *event)
{
	//qDebug()<<event->key()<<" ("<<event->text()<<") released."<<endl;

	switch(event->key())
	{
		case touchbuttons::Key_Touch_Left:
			if(ui->settingsButton->isDown())
			{
				ui->settingsButton->setDown(false);
				ui->settingsButton->click();
			}else{
				ui->settingsButton->setDown(false);
			}
			break;
		case touchbuttons::Key_Touch_Center:
			if(ui->backButton->isDown())
			{
				ui->backButton->setDown(false);
				ui->backButton->click();
			}else{
				ui->backButton->setDown(false);
			}
			break;
		case touchbuttons::Key_Touch_Right:
			if(ui->helpButton->isDown())
			{
				ui->helpButton->setDown(false);
				ui->helpButton->click();
			}else {
				ui->helpButton->setDown(false);
			}
			break;
		default:
			break;
	}
}

MainWindow::~MainWindow()
{
	delete ui;
}

void MainWindow::changeEvent(QEvent *e)
{
	QMainWindow::changeEvent(e);
	switch (e->type()) {
		case QEvent::LanguageChange:
			ui->retranslateUi(this);
			break;
		default:
			break;
	}
}
