#include "settingsdialog.h"
#include "ui_settingsdialog.h"
#include "../helpdialog.h"
#include "../touchbuttons.h"
#include "xdemreader.h"
#include "xdemwriter.h"
#include "editdialog.h"

#include <QDebug>
#include <QFileDialog>
#include <QMessageBox>

SettingsDialog::SettingsDialog(QWidget *parent) :
	QDialog(parent),
	ui(new Ui::SettingsDialog)
{
	ui->setupUi(this);

	// Maximize window to fullscreen
	this->showFullScreen();

	// Set backgroundcolor: white
	QPalette pal = this->palette();
	pal.setColor(QPalette::Window, Qt::white);
	this->setPalette(pal);

	//Connect signals and slots
	connect(ui->backButton, SIGNAL(clicked()), this, SLOT(backButtonClicked()));
	connect(ui->helpButton, SIGNAL(clicked()), this, SLOT(helpButtonClicked()));
	connect(ui->loadButton, SIGNAL(clicked()), this, SLOT(loadButtonClicked()));
	connect(ui->saveButton, SIGNAL(clicked()), this, SLOT(saveButtonClicked()));
	connect(ui->addButton, SIGNAL(clicked()), this, SLOT(addButtonClicked()));
	connect(ui->editButton, SIGNAL(clicked()), this, SLOT(editButtonClicked()));
	connect(ui->deleteButton, SIGNAL(clicked()), this, SLOT(deleteButtonClicked()));

	connect(ui->radioButtonIC, SIGNAL(clicked()), ui->tableWidgetIC, SLOT(show()));
	connect(ui->radioButtonIC, SIGNAL(clicked()), ui->tableWidgetQT, SLOT(hide()));

	connect(ui->radioButtonQT, SIGNAL(clicked()), ui->tableWidgetQT, SLOT(show()));
	connect(ui->radioButtonQT, SIGNAL(clicked()), ui->tableWidgetIC, SLOT(hide()));

	ui->radioButtonIC->click();

	QStringList headers;
	headers << "Name"<<"Location"<<"Description";
	ui->tableWidgetIC->setColumnCount(3);
	ui->tableWidgetIC->setHorizontalHeaderLabels(headers);
	ui->tableWidgetQT->setColumnCount(3);
	ui->tableWidgetQT->setHorizontalHeaderLabels(headers);

	maybesave = false;
}

void SettingsDialog::backButtonClicked()
{
	if(maybesave)
	{
		if((QMessageBox::information(NULL,
						"Save changes",
						"Apply all changes?",
						QMessageBox::Yes | QMessageBox::No,
						QMessageBox::Yes)) == QMessageBox::Yes)
		{
			writeXML(fileName);
		}
	}

	accept();

}

void SettingsDialog::helpButtonClicked()
{
	HelpDialog dialog;
	dialog.loadFile("qrc:///files/AppChooser_Settings_Help.html");
	dialog.exec();
}

void SettingsDialog::addButtonClicked()
{
	maybesave = true;

	int row =0;
	EditDialog dialog;
	if(dialog.exec() == QDialog::Accepted)
	{
		if(ui->radioButtonIC->isChecked())
		{
			row = ui->tableWidgetIC->currentRow();
			row++;
			ui->tableWidgetIC->insertRow(row);
			ui->tableWidgetIC->setItem(row, 0, new QTableWidgetItem(dialog.getName()));
			ui->tableWidgetIC->setItem(row, 1, new QTableWidgetItem(dialog.getFileName()));
			ui->tableWidgetIC->setItem(row, 2, new QTableWidgetItem(dialog.getDescription()));
		}else
		{
			row = ui->tableWidgetQT->currentRow();
			row++;
			ui->tableWidgetQT->insertRow(row);
			ui->tableWidgetQT->setItem(row, 0, new QTableWidgetItem(dialog.getName()));
			ui->tableWidgetQT->setItem(row, 1, new QTableWidgetItem(dialog.getFileName()));
			ui->tableWidgetQT->setItem(row, 2, new QTableWidgetItem(dialog.getDescription()));
		}
	}
}

void SettingsDialog::editButtonClicked()
{
	maybesave = true;

	int row = 0;
	EditDialog dialog;

	if(ui->radioButtonIC->isChecked())
	{
		row = ui->tableWidgetIC->currentRow();
		dialog.setName(ui->tableWidgetIC->item(row, 0)->text());
		dialog.setFileName(ui->tableWidgetIC->item(row, 1)->text());
		dialog.setDescription(ui->tableWidgetIC->item(row, 2)->text());

		if(dialog.exec() == QDialog::Accepted)
		{
			ui->tableWidgetIC->setItem(row, 0, new QTableWidgetItem(dialog.getName()));
			ui->tableWidgetIC->setItem(row, 1, new QTableWidgetItem(dialog.getFileName()));
			ui->tableWidgetIC->setItem(row, 2, new QTableWidgetItem(dialog.getDescription()));
		}
	}else
	{
		row = ui->tableWidgetQT->currentRow();
		dialog.setName(ui->tableWidgetQT->item(row, 0)->text());
		dialog.setFileName(ui->tableWidgetQT->item(row, 1)->text());
		dialog.setDescription(ui->tableWidgetQT->item(row, 2)->text());

		if(dialog.exec() == QDialog::Accepted)
		{
			ui->tableWidgetQT->setItem(row, 0, new QTableWidgetItem(dialog.getName()));
			ui->tableWidgetQT->setItem(row, 1, new QTableWidgetItem(dialog.getFileName()));
			ui->tableWidgetQT->setItem(row, 2, new QTableWidgetItem(dialog.getDescription()));
		}
	}

}

void SettingsDialog::deleteButtonClicked()
{
	maybesave = true;

	int row = 0;
	if(ui->radioButtonIC->isChecked())
	{
		if(ui->tableWidgetIC->rowCount() >= 1)
		{
			row = ui->tableWidgetIC->currentRow();
			ui->tableWidgetIC->removeRow(row);
		}
	}else
	{
		if(ui->tableWidgetQT->rowCount() >= 1)
		{
			row = ui->tableWidgetQT->currentRow();
			ui->tableWidgetQT->removeRow(row);
		}
	}
}

void SettingsDialog::saveButtonClicked()
{
	QString path =
		QFileDialog::getSaveFileName(this, tr("Save QDemo XML File"),
				QDir::currentPath(),
				tr("XDEM Files (*.xdem *.xml)"));
	//QString fileName = "test1.xdem";

	if (path.isEmpty())
		return;

	writeXML(path);

	maybesave = false;
}

void SettingsDialog::writeXML(QString path)
{
	QFile file(path);
	if (!file.open(QFile::WriteOnly | QFile::Text)) {
		QMessageBox::warning(this, tr("QXmlStream"),
				tr("Cannot write file %1:\n%2.")
				.arg(path)
				.arg(file.errorString()));
		return;
	}

	fileName = path;
	XdemWriter writer(ui->tableWidgetIC, ui->tableWidgetQT);
	writer.writeFile(&file);
}

void SettingsDialog::loadButtonClicked()
{
	QString path =
		QFileDialog::getOpenFileName(this, tr("Open QDemo XML File"),
				QDir::currentPath(),
				tr("XDEM Files (*.xdem *.xml)"));
	if (path.isEmpty())
		return;

	fileName = path;
	loadXML(fileName);

}

void SettingsDialog::loadXML(QString path)
{
	// Clear tableWidgets
	ui->tableWidgetIC->setRowCount(0);
	ui->tableWidgetQT->setRowCount(0);

	QFile file(path);
	if (!file.open(QFile::ReadOnly | QFile::Text)) {
		QMessageBox::warning(this, tr("QXmlStream"),
				tr("Cannot read file %1:\n%2.")
				.arg(path)
				.arg(file.errorString()));
		return;
	}

	XdemReader reader(ui->tableWidgetIC, ui->tableWidgetQT);
	if (!reader.read(&file)) {
		QMessageBox::warning(this, tr("QXmlStream Bookmarks"),
				tr("Parse error in file %1:\n\n%2")
				.arg(path)
				.arg(reader.errorString()));
	}

	fileName = path;
}

QString SettingsDialog::getFileName()
{
	return fileName;
}

void SettingsDialog::keyPressEvent(QKeyEvent *event)
{
	//qDebug()<<event->key()<<" ("<<event->text()<<") pressed."<<endl;

	switch(event->key())
	{
		case touchbuttons::Key_Touch_Left:
			ui->settingsButton->setDown(true);
			break;
		case touchbuttons::Key_Touch_Center:
			ui->backButton->setDown(true);
			break;
		case touchbuttons::Key_Touch_Right:
			ui->helpButton->setDown(true);
			break;
		default:
			break;
	}
}

void SettingsDialog::keyReleaseEvent(QKeyEvent *event)
{
	//qDebug()<<event->key()<<" ("<<event->text()<<") released."<<endl;

	switch(event->key())
	{
		case touchbuttons::Key_Touch_Left:
			if(ui->settingsButton->isDown())
			{
				ui->settingsButton->setDown(false);
				ui->settingsButton->click();
			}else{
				ui->settingsButton->setDown(false);
			}
			break;
		case touchbuttons::Key_Touch_Center:
			if(ui->backButton->isDown())
			{
				ui->backButton->setDown(false);
				ui->backButton->click();
			}else{
				ui->backButton->setDown(false);
			}
			break;
		case touchbuttons::Key_Touch_Right:
			if(ui->helpButton->isDown())
			{
				ui->helpButton->setDown(false);
				ui->helpButton->click();
			}else {
				ui->helpButton->setDown(false);
			}
			break;
		default:
			break;
	}
}

SettingsDialog::~SettingsDialog()
{
	delete ui;
}

void SettingsDialog::changeEvent(QEvent *e)
{
	QDialog::changeEvent(e);
	switch (e->type()) {
		case QEvent::LanguageChange:
			ui->retranslateUi(this);
			break;
		default:
			break;
	}
}
