#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H

#include <QDialog>

namespace Ui {
	class SettingsDialog;
}

/**
  A dialog to load/save/edit and create Demo-XML-files.
 */
class SettingsDialog : public QDialog {
	Q_OBJECT
	public:

		/**
		  Constructor.
		 */
		SettingsDialog(QWidget *parent = 0);

		/**
		  Destructor.
		 */
		~SettingsDialog();

		/**
		  Loads a XML and views its content in the tableWidget.
		  @param fileName the path to the XML-file
		 */
		void loadXML(QString fileName);

		/**
		  Returns the path to the current XML-file.
		  @returns the path to the current XML-file.
		 */
		QString getFileName();

	protected:
		void changeEvent(QEvent *e);

		/**
		  Reimplemented function.
		  This function is needed to provide functionality of
		  the 3 touch-buttons.
		 */
		virtual void  keyPressEvent(QKeyEvent *event);

		/**
		  Reimplemented function.
		  This function is needed to provide functionality of
		  the 3 touch-buttons.
		 */
		virtual void  keyReleaseEvent(QKeyEvent *event);

	private:
		Ui::SettingsDialog *ui;

		/**
		  Writes the information of the 2 Tables into a specific XML-file.
		  @param path filepath to XML-file
		 */
		void writeXML(QString path);

		bool maybesave; /**< Set to true, if changes occured */

		QString fileName; /**< Holds the path of the current XML-file */

	public slots:
		void backButtonClicked(); /**< Closes the application */
		void helpButtonClicked(); /**< Opens a help-dialog regarding this demo.*/
		void addButtonClicked(); /**< Opens an Edit-Dialog to add a new demo to the list. */
		void editButtonClicked(); /**< Opens an Edit-Dialog to edit the selected entry from the list */
		void deleteButtonClicked(); /**< Opens an Edit-Dialog to delete the selected entry from the list */
		void saveButtonClicked(); /**< Opens a FileDialog to save the demo-list to a XML-file */
		void loadButtonClicked(); /**< Opens a FileDialog to load a demo-list from a XML-file */

};

#endif // SETTINGSDIALOG_H
