#include "xdemreader.h"

#include <QTableWidget>

XdemReader::XdemReader(QTableWidget *tablewidgetIC, QTableWidget *tablewidgetQT) :
	tablewidgetIC(tablewidgetIC), tablewidgetQT(tablewidgetQT)
{
}

bool XdemReader::read(QIODevice *device)
{
	xml.setDevice(device);

	if (xml.readNextStartElement()) {
		if (xml.name() == "xdem" && xml.attributes().value("version") == "1.0")
			readXDEM();
		else
			xml.raiseError(QObject::tr("The file is not an XDEM version 1.0 file."));
	}

	return !xml.error();
}

QString XdemReader::errorString() const
{
	return QObject::tr("%1\nLine %2, column %3")
		.arg(xml.errorString())
		.arg(xml.lineNumber())
		.arg(xml.columnNumber());
}

void XdemReader::readXDEM()
{
	Q_ASSERT(xml.isStartElement() && xml.name() == "xdem");

	while (xml.readNextStartElement()) {
		if (xml.name() == "ICdemo")
			readTable(tablewidgetIC);
		else if (xml.name() == "QTdemo")
			readTable(tablewidgetQT);
		else
			xml.skipCurrentElement();
	}
}

void XdemReader::readTable(QTableWidget *table)
{

	while (xml.readNextStartElement()) {
		if (xml.name() == "application")
		{
			int rows = table->rowCount();
			table->insertRow(rows);

			while(xml.readNextStartElement())
			{
				if(xml.name() == "name")
					table->setItem(rows, 0, new QTableWidgetItem(xml.readElementText(), 0));
				else if(xml.name() == "location")
					table->setItem(rows, 1, new QTableWidgetItem(xml.readElementText(), 0));
				else if(xml.name() == "description")
					table->setItem(rows, 2, new QTableWidgetItem(xml.readElementText(), 0));
				else if(xml.name() == "arguments")
					table->setItem(rows, 3, new QTableWidgetItem(xml.readElementText(), 0));
				else
					xml.skipCurrentElement();
			}
		}
		else
			xml.skipCurrentElement();
	}

}
