#ifndef XDEMREADER_H
#define XDEMREADER_H

#include <QXmlStreamReader>

QT_BEGIN_NAMESPACE
class QTableWidget;
class QTableWidgetItem;
QT_END_NAMESPACE

/**
  This class reads information from a specific XML-file and
  fills it into the passed QTableWidgets.
 */
class XdemReader
{
	public:
		/**
		  Constructor.
		  @param tablewidgetIC pointer to QTableWidget that holds the IC-Demos
		  @param tableWidgetQT pointer to QTableWidget that holds the QT-Demos
		 */
		XdemReader(QTableWidget *tablewidgetIC, QTableWidget *tablewidgetQT);

		/**
		  Starts read process and checks version of XML-file.
		  @param device pointer to IOStream of the XML-file
		  @returns if successfull read from XML
		 */
		bool read(QIODevice *device);

		/**
		  Returns the errorString.
		  Contents errors created while reading from the XML-file.
		  This could be empty if no errors occurred.
		 */
		QString errorString() const;

	private:
		QTableWidget *tablewidgetIC; /**< Holds the pointer to QTableWidget that holds the IC-Demos */
		QTableWidget *tablewidgetQT; /**< Holds the pointer to QTableWidget that holds the QT-Demos */
		QXmlStreamReader xml; /**< QXmlStreamReader used for reading from the XML-file */

		/**
		  Reads the XML-file and fills the QTableWidgets.
		 */
		void readXDEM();

		/**
		  Function called by readXDEM() to fill the specific table.
		  @param table pointer to the current table that should be filled
		 */
		void readTable(QTableWidget *table);
};

#endif // XDEMREADER_H
