#include "mainwindow.h"
#include "ui_mainwindow.h"

#include "../touchbuttons.h"
#include "../helpdialog.h"

#include <QMouseDriverFactory>
#include <QDebug>

#define BRIGHTNESS_FILE	"/sys/class/backlight/pwm-backlight.1/brightness"
MainWindow::MainWindow(QWidget *parent) :
	QMainWindow(parent),
	ui(new Ui::MainWindow)
{
	ui->setupUi(this);

	// Maximize window to fullscreen
	this->showFullScreen();

	// Set backgroundcolor: white
	QPalette pal = this->palette();
	pal.setColor(QPalette::Window, Qt::white);
	this->setPalette(pal);

	//Connect signals and slots
	connect(ui->backButton, SIGNAL(clicked()), this, SLOT(backButtonClicked()));
	//connect(ui->settingsButton, SIGNAL(clicked()), this, SLOT(settingsButtonClicked()));
	connect(ui->helpButton, SIGNAL(clicked()), this, SLOT(helpButtonClicked()));
	connect(ui->setDefaultButton, SIGNAL(clicked()), this, SLOT(setDefaultButtonClicked()));
	connect(ui->backlightSlider, SIGNAL(valueChanged(int)), this, SLOT(setIntensity()));

	ui->backlightSlider->setValue(getIntensity());
}

void MainWindow::setIntensity()
{
	if(QFile::exists(BRIGHTNESS_FILE))
	{
		QFile blight(BRIGHTNESS_FILE);

		if(!blight.open(QIODevice::WriteOnly))
			return;

		blight.write(QString::number(ui->backlightSlider->value()).toAscii());
		blight.flush();

	}
}

int MainWindow::getIntensity()
{
	int intensity = 128;

	if(QFile::exists(BRIGHTNESS_FILE))
	{
		QFile blight(BRIGHTNESS_FILE);

		if(!blight.open(QIODevice::ReadOnly))
			return 128;

		QTextStream stream(&blight);

		intensity = stream.readAll().toInt();

	}

	return intensity;
}


void MainWindow::setDefaultButtonClicked()
{
	ui->backlightSlider->setValue(128);
}

void MainWindow::helpButtonClicked()
{
	HelpDialog dialog;
	dialog.loadURL("qrc:///files/Backlight_Demo_Help.html");
	dialog.exec();
}

void MainWindow::backButtonClicked()
{
	close();
}

void MainWindow::keyPressEvent(QKeyEvent *event)
{
	//qDebug()<<event->key()<<" ("<<event->text()<<") pressed."<<endl;

	switch(event->key())
	{
		case touchbuttons::Key_Touch_Left:
			ui->settingsButton->setDown(true);
			break;
		case touchbuttons::Key_Touch_Center:
			ui->backButton->setDown(true);
			break;
		case touchbuttons::Key_Touch_Right:
			ui->helpButton->setDown(true);
			break;
		default:
			break;
	}
}

void MainWindow::keyReleaseEvent(QKeyEvent *event)
{
	//qDebug()<<event->key()<<" ("<<event->text()<<") released."<<endl;

	switch(event->key())
	{
		case touchbuttons::Key_Touch_Left:
			if(ui->settingsButton->isDown())
			{
				ui->settingsButton->setDown(false);
				ui->settingsButton->click();
			}else{
				ui->settingsButton->setDown(false);
			}
			break;
		case touchbuttons::Key_Touch_Center:
			if(ui->backButton->isDown())
			{
				ui->backButton->setDown(false);
				ui->backButton->click();
			}else{
				ui->backButton->setDown(false);
			}
			break;
		case touchbuttons::Key_Touch_Right:
			if(ui->helpButton->isDown())
			{
				ui->helpButton->setDown(false);
				ui->helpButton->click();
			}else {
				ui->helpButton->setDown(false);
			}
			break;
		default:
			break;
	}
}

MainWindow::~MainWindow()
{
	delete ui;
}

void MainWindow::changeEvent(QEvent *e)
{
	QMainWindow::changeEvent(e);
	switch (e->type()) {
		case QEvent::LanguageChange:
			ui->retranslateUi(this);
			break;
		default:
			break;
	}
}
