#include "mainwindow.h"
#include "ui_mainwindow.h"

#include "../touchbuttons.h"
#include "../helpdialog.h"

#include <QProcess>
#include <QDebug>
#include <QApplication>

MainWindow::MainWindow(QWidget *parent) :
	QMainWindow(parent),
	ui(new Ui::MainWindow)
{
	ui->setupUi(this);

	// Maximize window to fullscreen
	this->showFullScreen();

	// Set backgroundcolor: white
	QPalette pal = this->palette();
	pal.setColor(QPalette::Window, Qt::white);
	this->setPalette(pal);

	//Connect signals and slots
	connect(ui->backButton, SIGNAL(clicked()), this, SLOT(backButtonClicked()));
	connect(ui->settingsButton, SIGNAL(clicked()), this, SLOT(settingsButtonClicked()));
	connect(ui->helpButton, SIGNAL(clicked()), this, SLOT(helpButtonClicked()));

}

void MainWindow::settingsButtonClicked()
{

}

void MainWindow::helpButtonClicked()
{
	HelpDialog dialog;
	dialog.loadURL("qrc:///files/dummy_Help.html");
	dialog.exec();
}

void MainWindow::backButtonClicked()
{
	close();
}

void MainWindow::keyPressEvent(QKeyEvent *event)
{
	qDebug()<<event->key()<<" ("<<event->text()<<") pressed.";

	switch(event->key())
	{
		case touchbuttons::Key_Touch_Left:
			ui->settingsButton->setDown(true);
			break;
		case touchbuttons::Key_Touch_Center:
			ui->backButton->setDown(true);
			break;
		case touchbuttons::Key_Touch_Right:
			ui->helpButton->setDown(true);
			break;
		default:
			break;
	}
}

void MainWindow::keyReleaseEvent(QKeyEvent *event)
{
	qDebug()<<event->key()<<" ("<<event->text()<<") released.";

	switch(event->key())
	{
		case touchbuttons::Key_Touch_Left:
			if(ui->settingsButton->isDown())
			{
				ui->settingsButton->setDown(false);
				ui->settingsButton->click();
			}else{
				ui->settingsButton->setDown(false);
			}
			break;
		case touchbuttons::Key_Touch_Center:
			if(ui->backButton->isDown())
			{
				ui->backButton->setDown(false);
				ui->backButton->click();
			}else{
				ui->backButton->setDown(false);
			}
			break;
		case touchbuttons::Key_Touch_Right:
			if(ui->helpButton->isDown())
			{
				ui->helpButton->setDown(false);
				ui->helpButton->click();
			}else {
				ui->helpButton->setDown(false);
			}
			break;
		default:
			break;
	}
}

MainWindow::~MainWindow()
{
	delete ui;
}

void MainWindow::changeEvent(QEvent *e)
{
	QMainWindow::changeEvent(e);
	switch (e->type()) {
		case QEvent::LanguageChange:
			ui->retranslateUi(this);
			break;
		default:
			break;
	}
}
