#include "settingsdialog.h"
#include "ui_settingsdialog.h"

#include <QFile>
#include <QTextStream>
#include <QKeyEvent>
#include <QDebug>
#include <QKeySequence>

#include "../helpdialog.h"
#include "../touchbuttons.h"

SettingsDialog::SettingsDialog(QWidget *parent) :
	QDialog(parent),
	ui(new Ui::SettingsDialog)
{
	ui->setupUi(this);

	// Set Backgroundcolor: White
	QPalette pal = this->palette();
	pal.setColor(QPalette::Window, Qt::white);
	this->setPalette(pal);

	this->showFullScreen();

	connect(ui->backButton, SIGNAL(clicked()), this, SLOT(backButtonClicked()));
	connect(ui->helpButton, SIGNAL(clicked()), this, SLOT(helpButtonClicked()));

	gpionumber = 0;

	initTable(":/files/IODemo.conf");
}

void SettingsDialog::initTable(QString file)
{
	ui->ioTable->setColumnCount(3);
	QStringList headers;
	headers << "IO"<<"Name"<<"Description";
	ui->ioTable->setHorizontalHeaderLabels(headers);
	int row = 0;

	// open config
	QFile conf(file);
	if(!conf.open(QFile::ReadOnly))
	{
		return;
	}
	QTextStream stream(&conf);

	QString line = stream.readLine(); // read first line

	while(!line.isEmpty())
	{
		if(!line.startsWith('#'))
		{
			// put line into table
			ui->ioTable->insertRow(row);

			QStringList list = line.split(';', QString::SkipEmptyParts);

			ui->ioTable->setItem(row, 0, new QTableWidgetItem(list.at(0), 0));
			ui->ioTable->setItem(row, 1, new QTableWidgetItem(list.at(1), 0));
			ui->ioTable->setItem(row, 2, new QTableWidgetItem(list.at(2), 0));

			row++;

		}else{
			// line starts with '#' -> ignore
		}
		line = stream.readLine(); // read next line
	}

}

int SettingsDialog::getNumber()
{
	return gpionumber;
}

void SettingsDialog::setNumber(int number)
{
	if(ui->ioTable->rowCount() == 0)
		return;

	gpionumber = number;

	int i=0;
	ui->ioTable->setCurrentCell(i, 0);

	while((ui->ioTable->item(ui->ioTable->currentRow(), 0)->text().toInt() != gpionumber) && i <= ui->ioTable->rowCount())
	{
		i++;
		ui->ioTable->setCurrentCell(i, 0);
	}

}

void SettingsDialog::loadConfig(QString file)
{
	initTable(file);
}

void SettingsDialog::backButtonClicked()
{
	if(ui->ioTable->rowCount() != 0)
	{
		gpionumber = ui->ioTable->item(ui->ioTable->currentRow(), 0)->text().toInt();
	}
	accept();
}

void SettingsDialog::helpButtonClicked()
{
	HelpDialog dialog;
	dialog.loadFile("qrc:///files/IODemo_Settings_Help.html");
	dialog.exec();
}

void SettingsDialog::keyPressEvent(QKeyEvent *event)
{
	//qDebug()<<event->key()<<" ("<<event->text()<<") pressed. -  settingsdialog"<<endl;

	switch(event->key())
	{
		case touchbuttons::Key_Touch_Left:
			ui->settingsButton->setDown(true);
			break;
		case touchbuttons::Key_Touch_Center:
			ui->backButton->setDown(true);
			break;
		case touchbuttons::Key_Touch_Right:
			ui->helpButton->setDown(true);
			break;
		default:
			break;
	}
}

void SettingsDialog::keyReleaseEvent(QKeyEvent *event)
{
	//qDebug()<<event->key()<<" ("<<event->text()<<") released. - settingsdialog"<<endl;

	switch(event->key())
	{
		case touchbuttons::Key_Touch_Left:
			if(ui->settingsButton->isDown())
			{
				ui->settingsButton->setDown(false);
				ui->settingsButton->click();
			}else{
				ui->settingsButton->setDown(false);
			}
			break;
		case touchbuttons::Key_Touch_Center:
			if(ui->backButton->isDown())
			{
				ui->backButton->setDown(false);
				ui->backButton->click();
			}else{
				ui->backButton->setDown(false);
			}
			break;
		case touchbuttons::Key_Touch_Right:
			if(ui->helpButton->isDown())
			{
				ui->helpButton->setDown(false);
				ui->helpButton->click();
			}else {
				ui->helpButton->setDown(false);
			}
			break;
		default:
			break;
	}

}


SettingsDialog::~SettingsDialog()
{
	delete ui;
}

void SettingsDialog::changeEvent(QEvent *e)
{
	QDialog::changeEvent(e);
	switch (e->type()) {
		case QEvent::LanguageChange:
			ui->retranslateUi(this);
			break;
		default:
			break;
	}
}
