#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H

#include <QDialog>

namespace Ui {
	class SettingsDialog;
}

/**
  A setup-dialog
 */
class SettingsDialog : public QDialog {
	Q_OBJECT
	public:
		/**
		  Constructor.
		 */
		SettingsDialog(QWidget *parent = 0);

		/**
		  Destructor.
		 */
		~SettingsDialog();

		/**
		  Returns the selected IO-number.
		  This number was selected by the user from the table.
		  @returns new IO number
		  @see setNumber
		 */
		int getNumber();

		/**
		  Defines the preselected number in the table.
		  @param number the current number to be shown in the table
		 */
		void setNumber(int number);

		/**
		  Loads a config file.
		  Offers the possibility to load a config different from "IODemo.conf".
		  @param file path to config-file
		 */
		void loadConfig(QString file);


	protected:
		/**
		  Initialises the table.
		  The information is provided by the passed config-file.
		  @param file path to config-file
		 */
		void initTable(QString file);

		void changeEvent(QEvent *e);

		/**
		  Reimplemented function.
		  Implemented for debugging. It catches key-presses and displays
		  them on the debug-console.
		 */
		virtual void  keyPressEvent(QKeyEvent *event);

		/**
		  Reimplemented function.
		  This function is needed to provide functionality of
		  the 3 touch-buttons. It catches key-releases and displays
		  them on the debug-console.
		 */
		virtual void  keyReleaseEvent(QKeyEvent *event);


	private:
		Ui::SettingsDialog *ui;

		int gpionumber; /**< IO-number*/

	public slots:
		void backButtonClicked();
		void helpButtonClicked();

};

#endif // SETTINGSDIALOG_H
