#include "mainwindow.h"
#include "ui_mainwindow.h"

#include "../touchbuttons.h"
#include "../helpdialog.h"

#include <QProcess>
#include <QDebug>
#include <QApplication>

#define BUZZER_DIR "/sys/devices/platform/pwm_buzzer.0/"
#define BUZZER_PERIOD	BUZZER_DIR "buzzer_period"
#define BUZZER_PW	BUZZER_DIR "buzzer"

MainWindow::MainWindow(QWidget *parent) :
	QMainWindow(parent),
	ui(new Ui::MainWindow)
{
	ui->setupUi(this);

	// Maximize window to fullscreen
	this->showFullScreen();

	// Set backgroundcolor: white
	QPalette pal = this->palette();
	pal.setColor(QPalette::Window, Qt::white);
	this->setPalette(pal);

	//Connect signals and slots
	connect(ui->backButton, SIGNAL(clicked()), this, SLOT(backButtonClicked()));
	//connect(ui->settingsButton, SIGNAL(clicked()), this, SLOT(settingsButtonClicked()));
	connect(ui->helpButton, SIGNAL(clicked()), this, SLOT(helpButtonClicked()));

	connect(ui->c1Button, SIGNAL(pressed()), this, SLOT(updateNote()));
	connect(ui->dButton, SIGNAL(pressed()), this, SLOT(updateNote()));
	connect(ui->eButton, SIGNAL(pressed()), this, SLOT(updateNote()));
	connect(ui->fButton, SIGNAL(pressed()), this, SLOT(updateNote()));
	connect(ui->gButton, SIGNAL(pressed()), this, SLOT(updateNote()));
	connect(ui->aButton, SIGNAL(pressed()), this, SLOT(updateNote()));
	connect(ui->hButton, SIGNAL(pressed()), this, SLOT(updateNote()));
	connect(ui->c2Button, SIGNAL(pressed()), this, SLOT(updateNote()));

	connect(ui->c1Button, SIGNAL(pressed()), this, SLOT(enableBuzzer()));
	connect(ui->dButton, SIGNAL(pressed()), this, SLOT(enableBuzzer()));
	connect(ui->eButton, SIGNAL(pressed()), this, SLOT(enableBuzzer()));
	connect(ui->fButton, SIGNAL(pressed()), this, SLOT(enableBuzzer()));
	connect(ui->gButton, SIGNAL(pressed()), this, SLOT(enableBuzzer()));
	connect(ui->aButton, SIGNAL(pressed()), this, SLOT(enableBuzzer()));
	connect(ui->hButton, SIGNAL(pressed()), this, SLOT(enableBuzzer()));
	connect(ui->c2Button, SIGNAL(pressed()), this, SLOT(enableBuzzer()));

	connect(ui->c1Button, SIGNAL(released()), this, SLOT(disableBuzzer()));
	connect(ui->dButton, SIGNAL(released()), this, SLOT(disableBuzzer()));
	connect(ui->eButton, SIGNAL(released()), this, SLOT(disableBuzzer()));
	connect(ui->fButton, SIGNAL(released()), this, SLOT(disableBuzzer()));
	connect(ui->gButton, SIGNAL(released()), this, SLOT(disableBuzzer()));
	connect(ui->aButton, SIGNAL(released()), this, SLOT(disableBuzzer()));
	connect(ui->hButton, SIGNAL(released()), this, SLOT(disableBuzzer()));
	connect(ui->c2Button, SIGNAL(released()), this, SLOT(disableBuzzer()));

}

void MainWindow::updateNote()
{
	int period = 1000000;

	if (ui->c1Button->isDown())
	{
		// c
		period = 1000000000 / 261.626; // period in nanoseconds

	}else if(ui->dButton->isDown())
	{
		// d
		period = 1000000000 / 293.665; // period in nanoseconds

	}else if(ui->eButton->isDown())
	{
		// e
		period = 1000000000 / 329.628; // period in nanoseconds

	}else if(ui->fButton->isDown())
	{
		// f
		period = 1000000000 / 349.228; // period in nanoseconds

	}else if(ui->gButton->isDown())
	{
		// g
		period = 1000000000 / 391.995; // period in nanoseconds

	}else if(ui->aButton->isDown())
	{
		// a
		period = 1000000000 / 440; // period in nanoseconds

	}else if(ui->hButton->isDown())
	{
		// h
		period = 1000000000 / 493.883; // period in nanoseconds

	}else if(ui->c2Button->isDown())
	{
		// C
		period = 1000000000 / 523.251; // period in nanoseconds

	}

	//qDebug() << "Period: " << period << endl;

	if(QFile::exists(BUZZER_PERIOD))
	{
		QFile buzzerPeriod(BUZZER_PERIOD);

		if(!buzzerPeriod.open(QIODevice::WriteOnly))
			return;

		buzzerPeriod.write(QString::number(period).toAscii());
		buzzerPeriod.flush();

		//qDebug()<<"Written"<< QString::number(period).toAscii() <<" to buzzer_period."<<endl;

	}

}

void MainWindow::enableBuzzer()
{
	if(QFile::exists(BUZZER_PW))
	{
		QFile buzzer(BUZZER_PW);

		if(!buzzer.open(QIODevice::WriteOnly))
			return;

		buzzer.write(QString::number(500).toAscii());
		buzzer.flush();

		//qDebug()<<"Enabled Buzzer."<<endl;

	}

}

void MainWindow::disableBuzzer()
{
	if(QFile::exists(BUZZER_PW))
	{
		QFile buzzer(BUZZER_PW);

		if(!buzzer.open(QIODevice::WriteOnly))
			return;

		buzzer.write(QString::number(0).toAscii());
		buzzer.flush();

		//qDebug()<<"Disabled Buzzer."<<endl;

	}

}

void MainWindow::helpButtonClicked()
{
	HelpDialog dialog;
	dialog.loadURL("qrc:///files/Piano_Demo_Help.html");
	dialog.exec();
}

void MainWindow::backButtonClicked()
{
	disableBuzzer();
	close();
}

void MainWindow::keyPressEvent(QKeyEvent *event)
{
	//qDebug()<<event->key()<<" ("<<event->text()<<") pressed."<<endl;

	switch(event->key())
	{
		case touchbuttons::Key_Touch_Left:
			ui->settingsButton->setDown(true);
			break;
		case touchbuttons::Key_Touch_Center:
			ui->backButton->setDown(true);
			break;
		case touchbuttons::Key_Touch_Right:
			ui->helpButton->setDown(true);
			break;
		default:
			break;
	}
}

void MainWindow::keyReleaseEvent(QKeyEvent *event)
{
	//qDebug()<<event->key()<<" ("<<event->text()<<") released."<<endl;

	switch(event->key())
	{
		case touchbuttons::Key_Touch_Left:
			if(ui->settingsButton->isDown())
			{
				ui->settingsButton->setDown(false);
				ui->settingsButton->click();
			}else{
				ui->settingsButton->setDown(false);
			}
			break;
		case touchbuttons::Key_Touch_Center:
			if(ui->backButton->isDown())
			{
				ui->backButton->setDown(false);
				ui->backButton->click();
			}else{
				ui->backButton->setDown(false);
			}
			break;
		case touchbuttons::Key_Touch_Right:
			if(ui->helpButton->isDown())
			{
				ui->helpButton->setDown(false);
				ui->helpButton->click();
			}else {
				ui->helpButton->setDown(false);
			}
			break;
		default:
			break;
	}
}

MainWindow::~MainWindow()
{
	delete ui;
}

void MainWindow::changeEvent(QEvent *e)
{
	QMainWindow::changeEvent(e);
	switch (e->type()) {
		case QEvent::LanguageChange:
			ui->retranslateUi(this);
			break;
		default:
			break;
	}
}
