#include "touchbuttons.h"
#include <QKeyEvent>
#include <QCoreApplication>
#include <QEvent>
#include <QApplication>

touchbuttons::touchbuttons()
{
	leftButtonPressed = false;
	rightButtonPressed = false;
	escapeReleased = false;
}

bool touchbuttons::eventFilter(QObject *obj, QEvent *event)
{
	QKeyEvent *keyEvent = NULL;//event data, if this is a keystroke event
	bool result = false;//return true to consume the keystroke

	if (event->type() == QEvent::KeyPress)
	{
		keyEvent = dynamic_cast<QKeyEvent*>(event);
		result = false;

		if(keyEvent->key() == Qt::Key_Home)
		{
			keyEvent = new QKeyEvent(QKeyEvent::KeyPress, touchbuttons::Key_Touch_Center, Qt::NoModifier, "back", 0, 0);
			QApplication::postEvent(obj, keyEvent);

			result = true;
		}

	}//if type()
	else if (event->type() == QEvent::KeyRelease)
	{
		keyEvent = dynamic_cast<QKeyEvent*>(event);
		result = false;

		switch(keyEvent->key())
		{

			case Qt::Key_Escape:
				escapeReleased = true;
				result = true;
				break;

			case Qt::Key_A:
				if(escapeReleased)
				{
					//'escape'-release + 'A'-release = 'leftTouchButton'-press/-release
					escapeReleased = false;
					if(leftButtonPressed)
					{
						// Left button was already pressed and now released
						//qDebug()<<"Left button released."<<endl;
						leftButtonPressed = false;
						keyEvent = new QKeyEvent(QKeyEvent::KeyRelease, touchbuttons::Key_Touch_Left, Qt::NoModifier, "settings", 0, 0);


					}else
					{
						// Left button now pressed
						//qDebug()<<"Left button pressed."<<endl;
						leftButtonPressed = true;
						keyEvent = new QKeyEvent(QKeyEvent::KeyPress, touchbuttons::Key_Touch_Left, Qt::NoModifier, "settings", 0, 0);
					}
					QApplication::postEvent(obj, keyEvent);
					result = true;
				}
				break;

			case Qt::Key_0:
				if(escapeReleased)
				{
					//'escape'-release + '0'-release = 'rightTouchButton'-press/-release
					escapeReleased = false;
					if(rightButtonPressed)
					{
						// Right button was already pressed and now released
						//qDebug()<<"Right button released."<<endl;
						rightButtonPressed = false;
						keyEvent = new QKeyEvent(QKeyEvent::KeyRelease, touchbuttons::Key_Touch_Right, Qt::NoModifier, "help", 0, 0);

					}else
					{
						// Right button now pressed
						//qDebug()<<"Right button pressed."<<endl;
						rightButtonPressed = true;
						keyEvent = new QKeyEvent(QKeyEvent::KeyPress, touchbuttons::Key_Touch_Right, Qt::NoModifier, "help", 0, 0);
					}
					QApplication::postEvent(obj, keyEvent);
					result = true;
				}
				break;

			case Qt::Key_Home:
				//qDebug()<<"Middle Button released."<<endl;
				keyEvent = new QKeyEvent(QKeyEvent::KeyRelease, touchbuttons::Key_Touch_Center, Qt::NoModifier, "back", 0, 0);
				QApplication::postEvent(obj, keyEvent);
				result = true;
				break;

			default:
				//qDebug("%d released", event->key());
				escapeReleased = false;
		}

	}//else if type()
	// Standard event processing
	else
		result = QObject::eventFilter(obj, event);
	return result;
}
