#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include "daemonize.h"

int reopen_fh(char *fn, int targetfh, int flags) {
	int fh, ret;
	if(fn == NULL) {
		close(targetfh);
		return 0;
	}

	fh = open(fn, flags);
	if(fh < 0) return -1;
	ret = dup2(fh, targetfh);
	//close(fh); ?
	return ret;
}

int detach(int detach) {
	int pid;

	if(!detach) return 0;
	// first fork, so that the parent can exit cleanly
	pid = fork();
	switch(pid) {
		case -1: // error
			return pid;
		case 0: // child (the forked process)
			break;
		default: // parent
			_exit(0);
	}

	if(setsid() < 0) 
		return -1;
	return 0;
}

int change_stdio(char *in, char *out, char *err) {
	reopen_fh(in, 0, O_RDONLY);
	reopen_fh(out, 1, O_WRONLY);
	reopen_fh(err, 2, O_WRONLY);
	return 0;
}

int daemonize(int daemonize, char *wd, char *in, char *out, char *err) {
	if(!daemonize) return 0;
	if(detach(daemonize) < 0) return -1;
	// second fork is recommended, but not really needed.
	if(wd != NULL) chdir(wd);
	// umask is recommended
	
	// reopen filehandles
	if(change_stdio(in, out, err) < 0) return -1;
	return 0;
}
