#include <sys/ioctl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <termios.h>
#include <unistd.h>
#include <string.h>
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <linux/tty.h>
#include "daemonize.h"
#include "read_config.h"
#include "options.h"
#include "setrs485.h"

read_config_decl(struct icbus_conf)

#ifndef N_ICBUS
#define N_ICBUS	25
#endif

int main(int argc, char **argv) {
	int fh, ldisc;
	struct icbus_conf conf;
	struct termios ttc;

	memset(&ttc, 0, sizeof(ttc));
	read_config(argc, argv, &conf);

	fh = open(conf.tty_arg, O_RDONLY| O_NOCTTY);
	if(fh <= 0) {
		fprintf(stderr, "Cant open tty %s: %s\n", conf.tty_arg, 
				strerror(errno));
		return -1;
	}
	cfmakeraw(&ttc);
	cfsetospeed(&ttc, B38400);
	cfsetispeed(&ttc, B0);
	if(tcsetattr(fh, TCSANOW, &ttc) < 0) {
		fprintf(stderr, "Cant setup line: %s\n", strerror(errno));
		return -1;
	}
	if((conf.rs485_given) && (setrs485(fh, conf.rs485_arg) < 0)) {
		fprintf(stderr, "Can't %sset RS485-Mode: %s\n",
				conf.rs485_arg?"":"un", strerror(errno));
		return -1;
	}
	ldisc = N_ICBUS;
	ioctl(fh, TIOCSETD, &ldisc);
	daemonize(conf.detach_flag, NULL, NULL, NULL, NULL);
	parser_free(&conf);
	select(0, NULL, NULL, NULL, NULL); // Sleep
	return 0;
}

